@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-#TODO: """DocString if there is one"""
+# TODO: """DocString if there is one"""
 
 from PyQt5.QtCore import pyqtProperty
 from PyQt5.QtWidgets import QWidget
@@ -11,8 +11,8 @@ import epyqlib.utils.qt
 
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class CompoundScale(QWidget):
@@ -39,7 +39,7 @@ class CompoundScale(QWidget):
         self.ui.echo.setHidden(hidden)
         self.ui.echo.ignore = True
 
-    @pyqtProperty('QString')
+    @pyqtProperty("QString")
     def command_signal_path(self):
         return self.ui.command.signal_path
 
@@ -47,7 +47,7 @@ class CompoundScale(QWidget):
     def command_signal_path(self, value):
         self.ui.command.signal_path = value
 
-    @pyqtProperty('QString')
+    @pyqtProperty("QString")
     def echo_signal_path(self):
         return self.ui.echo.signal_path
 
@@ -56,7 +56,7 @@ class CompoundScale(QWidget):
         self.ui.echo.signal_path = value
         self.update_echo_visibility()
 
-    @pyqtProperty('QString')
+    @pyqtProperty("QString")
     def status_signal_path(self):
         return self.ui.status.signal_path
 
@@ -189,8 +189,9 @@ class CompoundScale(QWidget):
         self.ui.status._colors[4] = color
         self.ui.status.update_configuration()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     import sys
 
-    print('No script functionality here')
-    sys.exit(1)     # non-zero is a failure
+    print("No script functionality here")
+    sys.exit(1)  # non-zero is a failure
