@@ -16,8 +16,8 @@ import epyqlib.twisted.nvs
 import epyqlib.utils.qt
 from epyqlib.tabs.files.log_manager import LogManager
 
-__copyright__ = 'Copyright 2017, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2017, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class UnsupportedError(Exception):
@@ -35,35 +35,37 @@ class DataLogger:
     rx_id = attr.ib(default=0x1FFFFFF7)
 
     def __attrs_post_init__(self):
-        signal = self.nvs.neo.signal_by_path('CCP', 'Connect', 'CommandCounter')
+        signal = self.nvs.neo.signal_by_path("CCP", "Connect", "CommandCounter")
         self.ccp_protocol = ccp.Handler(
-            endianness='little' if signal.little_endian else 'big',
+            endianness="little" if signal.little_endian else "big",
             tx_id=self.tx_id,
             rx_id=self.rx_id,
         )
         from twisted.internet import reactor
+
         self.ccp_transport = epyqlib.twisted.busproxy.BusProxy(
-            protocol=self.ccp_protocol,
-            reactor=reactor,
-            bus=self.bus)
-    
+            protocol=self.ccp_protocol, reactor=reactor, bus=self.bus
+        )
+
         self.nv_protocol = epyqlib.twisted.nvs.Protocol()
         self.nv_transport = epyqlib.twisted.busproxy.BusProxy(
-            protocol=self.nv_protocol,
-            reactor=reactor,
-            bus=self.bus)
+            protocol=self.nv_protocol, reactor=reactor, bus=self.bus
+        )
 
     def pull_raw_log(self, path):
         pull_fake_log = False
-        if (pull_fake_log):
+        if pull_fake_log:
             d = twisted.internet.defer.execute(self._pull_raw_log_fake)
         else:
             d = self._pull_raw_log()
         d.addCallback(write_to_file, path=path)
-        d.addCallback(lambda _: twisted.internet.defer.ensureDeferred(self._notify_new_raw_log(path)))
+        d.addCallback(
+            lambda _: twisted.internet.defer.ensureDeferred(
+                self._notify_new_raw_log(path)
+            )
+        )
 
-        d.addErrback(epyqlib.utils.twisted.detour_result,
-                     self.progress.fail)
+        d.addErrback(epyqlib.utils.twisted.detour_result, self.progress.fail)
         d.addErrback(epyqlib.utils.twisted.errbackhook)
 
         return d
@@ -73,17 +75,18 @@ class DataLogger:
     def _pull_raw_log_fake(self):
         self.progress.complete(message=None)
         from time import time
+
         return bytes(str(time()), "utf-8")
 
     async def _notify_new_raw_log(self, path: str):
-        build_hash_signal = self.nvs.signal_from_names('SoftwareHash', 'SoftwareHash')
-        serial_number_signal = self.nvs.signal_from_names('SN', 'SerialNumber')
+        build_hash_signal = self.nvs.signal_from_names("SoftwareHash", "SoftwareHash")
+        serial_number_signal = self.nvs.signal_from_names("SN", "SerialNumber")
 
         build_hash = await self.nv_protocol.read(
-                nv_signal=build_hash_signal,
-                meta=epyqlib.nv.MetaEnum.value,
-            )
-        build_hash = f'{build_hash[0]:07x}'
+            nv_signal=build_hash_signal,
+            meta=epyqlib.nv.MetaEnum.value,
+        )
+        build_hash = f"{build_hash[0]:07x}"
         serial_number = await self.nv_protocol.read(
             nv_signal=serial_number_signal,
             meta=epyqlib.nv.MetaEnum.value,
@@ -95,22 +98,25 @@ class DataLogger:
     @twisted.internet.defer.inlineCallbacks
     def _pull_raw_log(self):
         unsupported = UnsupportedError(
-                'Pull of raw log is not supported for this device',
+            "Pull of raw log is not supported for this device",
         )
 
         try:
             recording_signal = self.nvs.signal_from_names(
-                'DataloggerStatus', 'DataloggerRecording')
+                "DataloggerStatus", "DataloggerRecording"
+            )
         except epyqlib.nv.NotFoundError as e:
             raise unsupported from e
 
         try:
             readable_octets_signal = self.nvs.signal_from_names(
-                'LoggerStatus01', 'ReadableOctets')
+                "LoggerStatus01", "ReadableOctets"
+            )
         except epyqlib.nv.NotFoundError as e:
             raise unsupported from e
 
         from twisted.internet import reactor
+
         while True:
             recording = yield self.nv_protocol.read(
                 nv_signal=recording_signal,
@@ -141,20 +147,20 @@ class DataLogger:
             address_extension=ccp.AddressExtension.data_logger,
             address=0,
             octets=readable_octets,
-            progress=self.progress
+            progress=self.progress,
         )
         yield self.ccp_protocol.disconnect(end_of_session=1)
 
         seconds = self.progress.elapsed()
 
-        completed_format = textwrap.dedent('''\
+        completed_format = textwrap.dedent(
+            """\
         Log successfully pulled
 
-        Data time: {seconds:.3f} seconds for {bytes} bytes or {bps:.0f} bytes/second''')
+        Data time: {seconds:.3f} seconds for {bytes} bytes or {bps:.0f} bytes/second"""
+        )
         message = completed_format.format(
-            seconds=seconds,
-            bytes=readable_octets,
-            bps=readable_octets / seconds
+            seconds=seconds, bytes=readable_octets, bps=readable_octets / seconds
         )
 
         self.progress.complete(message=message)
@@ -163,7 +169,7 @@ class DataLogger:
 
 
 def write_to_file(data, path):
-    with open(path, 'wb') as f:
+    with open(path, "wb") as f:
         f.write(data)
 
 
@@ -171,10 +177,7 @@ def pull_raw_log(device, bus=None, parent=None):
     if bus is None:
         bus = device.bus
 
-    filters = [
-        ('Raw', ['raw']),
-        ('All Files', ['*'])
-    ]
+    filters = [("Raw", ["raw"]), ("All Files", ["*"])]
     filename = epyqlib.utils.qt.file_dialog(filters, save=True, parent=parent)
 
     # TODO: perhaps an exception for cancelation?  let caller ignore it?
@@ -189,25 +192,24 @@ def pull_raw_log(device, bus=None, parent=None):
         nvs=device.nvs,
         bus=bus,
         device=device,
-        tx_id=device.neo_frames.frame_by_name('CCP').id,
-        rx_id=device.neo_frames.frame_by_name('CCPResponse').id,
+        tx_id=device.neo_frames.frame_by_name("CCP").id,
+        rx_id=device.neo_frames.frame_by_name("CCPResponse").id,
     )
 
     logger.progress.connect(
         progress=progress,
-        label_text=('Pulling log...\n\n'
-                    + logger.progress.default_progress_label)
+        label_text=("Pulling log...\n\n" + logger.progress.default_progress_label),
     )
     return logger.pull_raw_log(path=filename)
 
 
 def generate_records(
-        cache,
-        chunks,
-        data_stream,
-        variables_and_chunks,
-        sample_period_us,
-        raw_chunks,
+    cache,
+    chunks,
+    data_stream,
+    variables_and_chunks,
+    sample_period_us,
+    raw_chunks,
 ):
     chunk_list = list(chunks)
 
@@ -217,20 +219,20 @@ def generate_records(
         data_stream.seek(-1, io.SEEK_CUR)
 
         row = collections.OrderedDict()
-        row['.time'] = timestamp / 1000000
+        row[".time"] = timestamp / 1000000
         timestamp += sample_period_us
 
         def update(data, variable, scaling_cache):
-            path = '.'.join(variable.path())
+            path = ".".join(variable.path())
             value = variable.variable.unpack(data)
             type_ = variable.fields.type
             scaling = 1
             if type_ in scaling_cache:
                 scaling = scaling_cache[type_]
             else:
-                if type_.startswith('_iq'):
-                    n = type_.lstrip('_iq')
-                    if n == '':
+                if type_.startswith("_iq"):
+                    n = type_.lstrip("_iq")
+                    if n == "":
                         n = 24
                     else:
                         n = int(n)
@@ -241,18 +243,17 @@ def generate_records(
 
         for variable, chunk in variables_and_chunks.items():
             partial = functools.partial(
-                update,
-                variable=variable,
-                scaling_cache=scaling_cache
+                update, variable=variable, scaling_cache=scaling_cache
             )
             cache.subscribe(partial, chunk)
 
         for chunk in raw_chunks:
-            chunk_bytes = bytearray(
-                data_stream.read(len(chunk)))
+            chunk_bytes = bytearray(data_stream.read(len(chunk)))
             if len(chunk_bytes) != len(chunk):
-                text = ("Unexpected EOF found in the middle of a record.  "
-                        "Continuing with partially extracted log.")
+                text = (
+                    "Unexpected EOF found in the middle of a record.  "
+                    "Continuing with partially extracted log."
+                )
                 raise EOFError(text)
 
             chunk.set_bytes(chunk_bytes)
@@ -263,15 +264,15 @@ def generate_records(
 
 
 def parse_log(
-        cache,
-        chunks,
-        csv_path,
-        data_stream,
-        variables_and_chunks,
-        sample_period_us,
-        raw_chunks,
+    cache,
+    chunks,
+    csv_path,
+    data_stream,
+    variables_and_chunks,
+    sample_period_us,
+    raw_chunks,
 ):
-    with open(csv_path, 'w', newline='') as f:
+    with open(csv_path, "w", newline="") as f:
         writer = None
 
         records = generate_records(
@@ -286,8 +287,7 @@ def parse_log(
         for row in records:
             if writer is None:
                 writer = csv.DictWriter(
-                    f,
-                    fieldnames=sorted(row.keys(), key=str.casefold)
+                    f, fieldnames=sorted(row.keys(), key=str.casefold)
                 )
                 writer.writeheader()
 
