@@ -7,13 +7,15 @@ import pytest
 from epyqlib.tabs.files.sync_config import SyncConfig, ConfigurationError, Vars
 
 tempdir = tempfile.gettempdir()
-filename = f'test-{int(time.time()) % 100000}.json'
+filename = f"test-{int(time.time()) % 100000}.json"
 full_path = os.path.join(tempdir, filename)
 
+
 def load_configuration():
-    print(f'Using temp dir {full_path}')
+    print(f"Using temp dir {full_path}")
     return SyncConfig(tempdir, filename)
 
+
 def cleanup():
     os.unlink(full_path)
 
@@ -31,11 +33,8 @@ def test_read():
 
 
 def test_invalid_json():
-    with open(full_path, 'w') as file:
+    with open(full_path, "w") as file:
         file.write("[1,2,3]")
     with pytest.raises(ConfigurationError):
         load_configuration()
     cleanup()
-
-
-
