@@ -9,12 +9,12 @@ import epyqlib.hildevice
 
 @pytest.fixture
 def factory_definition():
-    original = pathlib.Path(epyqlib.tests.common.devices['factory'])
+    original = pathlib.Path(epyqlib.tests.common.devices["factory"])
     with epyqlib.updateepc.updated(original) as updated:
         return epyqlib.hildevice.Definition.loadp(updated)
 
 
-@pytest.mark.parametrize('version', [[1], [3]])
+@pytest.mark.parametrize("version", [[1], [3]])
 def test_definition_format_version_validator(factory_definition, version):
     with pytest.raises(epyqlib.hildevice.FormatVersionError):
         attr.evolve(factory_definition, format_version=version)
@@ -26,7 +26,7 @@ def test_definition_load(factory_definition):
 
 
 def test_definition_loads():
-    path = pathlib.Path(epyqlib.tests.common.devices['factory'])
+    path = pathlib.Path(epyqlib.tests.common.devices["factory"])
 
     with epyqlib.updateepc.updated(path) as updated:
         with open(updated) as f:
@@ -40,14 +40,14 @@ def test_definition_loads():
 
 def test_load():
     device = epyqlib.hildevice.Device(
-        definition_path=epyqlib.tests.common.devices['factory'],
+        definition_path=epyqlib.tests.common.devices["factory"],
     )
     device.load()
 
 
 def test_device_reload():
     device = epyqlib.hildevice.Device(
-        definition_path=epyqlib.tests.common.devices['factory'],
+        definition_path=epyqlib.tests.common.devices["factory"],
     )
     device.load()
 
