@@ -4,35 +4,40 @@ import epyqlib.pyqabstractitemmodel
 from epyqlib.abstractcolumns import AbstractColumns
 import epyqlib.canneo
 from epyqlib.treenode import TreeNode
-from PyQt5.QtCore import (Qt, QVariant, QModelIndex, pyqtSignal, QTimer)
+from PyQt5.QtCore import Qt, QVariant, QModelIndex, pyqtSignal, QTimer
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class SignalNode(epyqlib.canneo.Signal, TreeNode):
-    def __init__(self, signal, frame, tx=False, connect=None, tree_parent=None, parent=None):
-        epyqlib.canneo.Signal.__init__(self, signal=signal, frame=frame, connect=connect, parent=parent)
+    def __init__(
+        self, signal, frame, tx=False, connect=None, tree_parent=None, parent=None
+    ):
+        epyqlib.canneo.Signal.__init__(
+            self, signal=signal, frame=frame, connect=connect, parent=parent
+        )
         TreeNode.__init__(self, tx=tx, parent=tree_parent)
 
-        self.fields = Columns(id=self.start_bit,
-                              name=self.name,
-                              length='{} b'.format(self.signal_size),
-                              value='-',
-                              dt='-',
-                              count='')
+        self.fields = Columns(
+            id=self.start_bit,
+            name=self.name,
+            length="{} b".format(self.signal_size),
+            value="-",
+            dt="-",
+            count="",
+        )
         self.last_time = None
 
     def unique(self):
         # TODO: make it more unique
-        return str(self.fields.id) + '__'
+        return str(self.fields.id) + "__"
 
     def set_value(self, value, force=False, check_range=False):
-        epyqlib.canneo.Signal.set_value(self,
-                                        value=value,
-                                        force=force,
-                                        check_range=check_range)
+        epyqlib.canneo.Signal.set_value(
+            self, value=value, force=force, check_range=check_range
+        )
         self.fields.value = self.full_string
 
     def set_data(self, data):
@@ -45,15 +50,26 @@ class SignalNode(epyqlib.canneo.Signal, TreeNode):
 
 
 class MessageNode(epyqlib.canneo.Frame, TreeNode):
-    def __init__(self, message=None, tx=False, frame=None,
-                 multiplex_value=None, signal_class=SignalNode,
-                 mux_frame=None, parent=None, **kwargs):
-        epyqlib.canneo.Frame.__init__(self, frame=frame,
-                                   multiplex_value=multiplex_value,
-                                   signal_class=signal_class,
-                                   mux_frame=mux_frame,
-                                   parent=parent,
-                                   **kwargs)
+    def __init__(
+        self,
+        message=None,
+        tx=False,
+        frame=None,
+        multiplex_value=None,
+        signal_class=SignalNode,
+        mux_frame=None,
+        parent=None,
+        **kwargs,
+    ):
+        epyqlib.canneo.Frame.__init__(
+            self,
+            frame=frame,
+            multiplex_value=multiplex_value,
+            signal_class=signal_class,
+            mux_frame=mux_frame,
+            parent=parent,
+            **kwargs,
+        )
         TreeNode.__init__(self, parent)
 
         self.fields = Columns()
@@ -63,8 +79,8 @@ class MessageNode(epyqlib.canneo.Frame, TreeNode):
         self._send_checked = False
 
         self.count = {
-            'tx': 0,
-            'rx': 0,
+            "tx": 0,
+            "rx": 0,
         }
 
         for signal in self.signals:
@@ -76,16 +92,18 @@ class MessageNode(epyqlib.canneo.Frame, TreeNode):
         if self.mux_name is None:
             name = self.name
         else:
-            name = '{} - {}'.format(self.name, self.mux_name)
+            name = "{} - {}".format(self.name, self.mux_name)
 
-        count = self.count['tx'] if self.tx else self.count['rx']
+        count = self.count["tx"] if self.tx else self.count["rx"]
 
-        self.fields = Columns(id=identifier,
-                              name=name,
-                              length='{} B'.format(self.size),
-                              value='-',
-                              dt='-',
-                              count=str(count))
+        self.fields = Columns(
+            id=identifier,
+            name=name,
+            length="{} B".format(self.size),
+            value="-",
+            dt="-",
+            count=str(count),
+        )
 
     @property
     def send_checked(self):
@@ -119,7 +137,7 @@ class MessageNode(epyqlib.canneo.Frame, TreeNode):
     def dt(self, value):
         old = self.fields.dt
 
-        if value == '':
+        if value == "":
             self.fields.dt = value
             self.send_checked = Qt.Unchecked
         else:
@@ -149,39 +167,43 @@ class MessageNode(epyqlib.canneo.Frame, TreeNode):
         # self.message = message
 
         self.fields.id = epyqlib.canneo.format_identifier(
-                message.arbitration_id, message.id_type)
+            message.arbitration_id, message.id_type
+        )
 
         # self.fields.name = self.name
 
-        self.fields.length = '{} B'.format(message.dlc)
+        self.fields.length = "{} B".format(message.dlc)
         self.fields.value = epyqlib.canneo.format_data(tuple(message.data))
         # if self.last_time == message.timestamp:
         #     raise Exception('message already received {message}'
         #                     .format(**locals()))
         if self.last_time is None:
-            self.fields.dt = '-'
+            self.fields.dt = "-"
         else:
-            self.fields.dt = '{:.4f}'.format(message.timestamp - self.last_time)
+            self.fields.dt = "{:.4f}".format(message.timestamp - self.last_time)
         self.last_time = message.timestamp
 
-        self.count['rx'] += 1
+        self.count["rx"] += 1
 
         if not self.tx:
-            self.fields.count = str(self.count['rx'])
+            self.fields.count = str(self.count["rx"])
 
         epyqlib.canneo.Frame.message_received(self, message)
 
     def _sent(self):
         super()._sent()
 
-        self.count['tx'] += 1
+        self.count["tx"] += 1
 
         if self.tx:
-            self.fields.count = str(self.count['tx'])
+            self.fields.count = str(self.count["tx"])
             self.tree_parent.changed.emit(
-                self, Columns.indexes.count,
-                self, Columns.indexes.count,
-                [Qt.DisplayRole])
+                self,
+                Columns.indexes.count,
+                self,
+                Columns.indexes.count,
+                [Qt.DisplayRole],
+            )
 
     def message_received(self, msg):
         super().message_received(msg=msg)
@@ -236,8 +258,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
                 self.add_message_node(node=frame)
 
         if self.bus is not None:
-            self.remapper = epyqlib.canneo.QtCanListener(
-                receiver=self.message_sent)
+            self.remapper = epyqlib.canneo.QtCanListener(receiver=self.message_sent)
             self.bus.tx_notifier.add(self.remapper)
             self.sent_messages = {}
 
@@ -246,12 +267,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
         #       Rx will add in order received
         self.children.sort(key=lambda c: c.name)
 
-        self.fields = Columns(id='',
-                      name='',
-                      length='',
-                      value='',
-                      dt='',
-                      count='')
+        self.fields = Columns(id="", name="", length="", value="", dt="", count="")
 
         self.update_timer = QTimer()
         # 81 seems to provide nice variation in the count on 10ms messages
@@ -266,10 +282,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
         #       overwritten while they were being edited keeping the user
         #       from actually being able to change them
         if self.rx:
-            self.changed.emit(
-                self, 0,
-                self, 1,
-                [Qt.DisplayRole])
+            self.changed.emit(self, 0, self, 1, [Qt.DisplayRole])
 
     def set_node_id(self, node_id):
         # TODO: I think this can go away
@@ -288,7 +301,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
                     id=message.arbitration_id,
                     extended=message.is_extended_id,
                 ),
-                name='',
+                name="",
                 size=message.dlc,
             )
             message_node = MessageNode(message=message, tx=tx, frame=frame)
@@ -315,9 +328,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
     def generate_id(self, message):
         multiplex_value = self.neo.get_multiplex(message)[1]
 
-        return (message.arbitration_id,
-                message.id_type,
-                multiplex_value)
+        return (message.arbitration_id, message.id_type, multiplex_value)
 
     def message_received(self, msg):
         id = self.generate_id(message=msg)
@@ -325,8 +336,7 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
         try:
             message = self.messages[id]
         except KeyError:
-            self.add_message(message=msg,
-                             id=id)
+            self.add_message(message=msg, id=id)
             message = self.messages[id]
 
         message.extract_message(msg)
@@ -363,17 +373,18 @@ class TxRx(TreeNode, epyqlib.canneo.QtCanListener):
 
     def unique(self):
         # TODO: actually identify the object
-        return '-'
+        return "-"
 
     def send(self, message, on_success=None):
         self.bus.send(message, on_success=on_success)
 
     def __str__(self):
-        return 'Indexes: \n' + '\n'.join([str(i) for i in self.children])
+        return "Indexes: \n" + "\n".join([str(i) for i in self.children])
 
 
 class Columns(AbstractColumns):
-    _members = ['id', 'length', 'name', 'value', 'dt', 'count']
+    _members = ["id", "length", "name", "value", "dt", "count"]
+
 
 Columns.indexes = Columns.indexes()
 
@@ -385,15 +396,17 @@ class TxRxModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
             checkbox_columns.dt = True
 
         epyqlib.pyqabstractitemmodel.PyQAbstractItemModel.__init__(
-                self, root=root, checkbox_columns=checkbox_columns,
-                parent=parent)
+            self, root=root, checkbox_columns=checkbox_columns, parent=parent
+        )
 
-        self.headers = Columns(id='ID',
-                               length='Length',
-                               name='Name',
-                               value='Value',
-                               dt='Cycle Time',
-                               count='Count')
+        self.headers = Columns(
+            id="ID",
+            length="Length",
+            name="Name",
+            value="Value",
+            dt="Cycle Time",
+            count="Count",
+        )
 
     def flags(self, index):
         flags = epyqlib.pyqabstractitemmodel.PyQAbstractItemModel.flags(self, index)
@@ -402,7 +415,7 @@ class TxRxModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         if node.tx:
             if index.column() == Columns.indexes.value:
                 if isinstance(node, SignalNode):
-                    allow = not node.multiplex
+                    allow = node.multiplex is not True
                 else:
                     allow = False
 
