@@ -6,8 +6,8 @@ import epyqlib.utils.qt
 
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class TxRxView(QtWidgets.QWidget):
@@ -38,27 +38,31 @@ class TxRxView(QtWidgets.QWidget):
         for i in epyqlib.txrx.Columns.indexes:
             if self.resize_columns[i]:
                 self.ui.tree_view.header().setSectionResizeMode(
-                    i, QtWidgets.QHeaderView.ResizeToContents)
+                    i, QtWidgets.QHeaderView.ResizeToContents
+                )
             else:
                 # at least fit the column headers and/or initial data
                 self.ui.tree_view.resizeColumnToContents(i)
 
         self.ui.tree_view.header().setSectionResizeMode(
-            epyqlib.txrx.Columns.indexes.name, QtWidgets.QHeaderView.Stretch)
+            epyqlib.txrx.Columns.indexes.name, QtWidgets.QHeaderView.Stretch
+        )
 
         self.ui.tree_view.setItemDelegateForColumn(
             epyqlib.txrx.Columns.indexes.value,
             epyqlib.delegates.ByFunction(
                 model=self.nonproxy_model(),
                 parent=self,
-            )
+            ),
         )
 
-        self.ui.tree_view.setColumnWidth(epyqlib.txrx.Columns.indexes.value,
-                                         self.calculate_max_value_width())
-        self.ui.tree_view.setColumnWidth(epyqlib.txrx.Columns.indexes.id,
-                                         self.calculate_max_id_width() +
-                                         self.ui.tree_view.indentation())
+        self.ui.tree_view.setColumnWidth(
+            epyqlib.txrx.Columns.indexes.value, self.calculate_max_value_width()
+        )
+        self.ui.tree_view.setColumnWidth(
+            epyqlib.txrx.Columns.indexes.id,
+            self.calculate_max_id_width() + self.ui.tree_view.indentation(),
+        )
 
     # TODO: CAMPid 07943342700734207878034207087
     def nonproxy_model(self):
@@ -71,21 +75,21 @@ class TxRxView(QtWidgets.QWidget):
     # TODO: CAMPid 989849193479134917954791341
     def calculate_max_value_width(self):
         metric = self.ui.tree_view.fontMetrics()
-        chars = ['{:X}'.format(i) for i in range(16)]
+        chars = ["{:X}".format(i) for i in range(16)]
         widths = [metric.width(c) for c in chars]
         widest_width = max(widths)
         widest_char = chars[widths.index(widest_width)]
-        string = ' '.join([widest_char * 2] * 8)
+        string = " ".join([widest_char * 2] * 8)
         return metric.width(string)
 
     # TODO: CAMPid 989849193479134917954791341
     def calculate_max_id_width(self):
         metric = self.ui.tree_view.fontMetrics()
-        chars = ['{:X}'.format(i) for i in range(16)]
+        chars = ["{:X}".format(i) for i in range(16)]
         widths = [metric.width(c) for c in chars]
         widest_width = max(widths)
         widest_char = chars[widths.index(widest_width)]
-        string = '0x{}'.format(widest_char * 8)
+        string = "0x{}".format(widest_char * 8)
         return metric.width(string)
 
     def set_sorting_enabled(self, enabled):
